@@ -129,6 +129,7 @@ VALID_OPTS = {
     'client_acl_blacklist': dict,
     'external_auth': dict,
     'token_expire': int,
+    'file_recv': bool,
     'file_ignore_regex': bool,
     'file_ignore_glob': bool,
     'fileserver_backend': list,
@@ -270,6 +271,7 @@ DEFAULT_MASTER_OPTS = {
     'client_acl_blacklist': {},
     'external_auth': {},
     'token_expire': 43200,
+    'file_recv': False,
     'file_buffer_size': 1048576,
     'file_ignore_regex': None,
     'file_ignore_glob': None,
