@@ -876,6 +876,15 @@ def os_data():
         grains['os_family'] = _OS_FAMILY_MAP.get(grains['os'],
                                                  grains['os'])
 
+    # Build the osarch grain. This grain will be used for platform-specific
+    # considerations such as package management. Fall back to the CPU
+    # architecture.
+    if grains.get('os_family') == 'Debian':
+        osarch = __salt__['cmd.run']('dpkg --print-architecture').strip()
+    else:
+        osarch = grains['cpuarch']
+    grains['osarch'] = osarch
+
     grains.update(_memdata(grains))
 
     # Get the hardware and bios data
@@ -884,9 +893,20 @@ def os_data():
     # Load the virtual machine info
     grains.update(_virtual(grains))
     grains.update(_ps(grains))
+
+    # Load additional OS family grains
     if grains['os_family'] == "RedHat":
         grains['osmajorrelease'] = grains['osrelease'].split('.', 1)
 
+        grains['osfinger'] = '{os}-{ver}'.format(
+                os=grains['osfullname'],
+                ver=grains['osrelease'].partition('.')[0])
+    elif grains.get('osfullname') == 'Ubuntu':
+        grains['osfinger'] = '{os}-{ver}'.format(
+                os=grains['osfullname'],
+                ver=grains['osrelease'])
+
+
     return grains
 
 
