@@ -5,6 +5,9 @@ Module for gathering disk information
 # Import python libs
 import logging
 
+# Import salt libs
+import salt.utils
+
 log = logging.getLogger(__name__)
 
 
@@ -12,11 +15,7 @@ def __virtual__():
     '''
     Only work on POSIX-like systems
     '''
-    # Disable on these platforms, specific service modules exist:
-    disable = [
-        'Windows',
-        ]
-    if __grains__['os'] in disable:
+    if salt.utils.is_windows():
         return False
     return 'disk'
 
@@ -45,14 +44,29 @@ def usage(args=None):
         if line.startswith('Filesystem'):
             continue
         comps = line.split()
+        while not comps[1].isdigit():
+            comps[0] = '{0} {1}'.format(comps[0], comps[1])
+            comps.pop(1)
         try:
-            ret[comps[5]] = {
-                'filesystem': comps[0],
-                '1K-blocks':  comps[1],
-                'used':       comps[2],
-                'available':  comps[3],
-                'capacity':   comps[4],
-            }
+            if __grains__['kernel'] == 'Darwin':
+                ret[comps[8]] = {
+                        'filesystem': comps[0],
+                        '512-blocks': comps[1],
+                        'used': comps[2],
+                        'available': comps[3],
+                        'capacity': comps[4],
+                        'iused': comps[5],
+                        'ifree': comps[6],
+                        '%iused': comps[7],
+                }
+            else:
+                ret[comps[5]] = {
+                        'filesystem': comps[0],
+                        '1K-blocks': comps[1],
+                        'used': comps[2],
+                        'available': comps[3],
+                        'capacity': comps[4],
+                }
         except IndexError:
             log.warn("Problem parsing disk usage information")
             ret = {}
