@@ -129,28 +129,39 @@ def group_to_gid(group):
         return ''
 
 
-def get_gid(path):
+def get_gid(path, follow_symlinks=True):
     '''
     Return the id of the group that owns a given file
 
     CLI Example::
 
         salt '*' file.get_gid /etc/passwd
+
+    .. versionchanged:: 0.16.4
+        ``follow_symlinks`` option added
     '''
     if not os.path.exists(path):
+        try:
+            # Broken symlinks will return false, but still have a uid and gid
+            return os.lstat(path).st_gid
+        except OSError:
+            pass
         return -1
-    return os.stat(path).st_gid
+    return os.stat(path).st_gid if follow_symlinks else os.lstat(path).st_gid
 
 
-def get_group(path):
+def get_group(path, follow_symlinks=True):
     '''
     Return the group that owns a given file
 
     CLI Example::
 
         salt '*' file.get_group /etc/passwd
+
+    .. versionchanged:: 0.16.4
+        ``follow_symlinks`` option added
     '''
-    gid = get_gid(path)
+    gid = get_gid(path, follow_symlinks)
     if gid == -1:
         return False
     return gid_to_group(gid)
@@ -186,28 +197,39 @@ def user_to_uid(user):
         return ''
 
 
-def get_uid(path):
+def get_uid(path, follow_symlinks=True):
     '''
     Return the id of the user that owns a given file
 
     CLI Example::
 
         salt '*' file.get_uid /etc/passwd
+
+    .. versionchanged:: 0.16.4
+        ``follow_symlinks`` option added
     '''
     if not os.path.exists(path):
-        return False
-    return os.stat(path).st_uid
+        try:
+            # Broken symlinks will return false, but still have a uid and gid
+            return os.lstat(path).st_uid
+        except OSError:
+            pass
+        return -1
+    return os.stat(path).st_uid if follow_symlinks else os.lstat(path).st_uid
 
 
-def get_user(path):
+def get_user(path, follow_symlinks=True):
     '''
     Return the user that owns a given file
 
     CLI Example::
 
         salt '*' file.get_user /etc/passwd
+
+    .. versionchanged:: 0.16.4
+        ``follow_symlinks`` option added
     '''
-    uid = get_uid(path)
+    uid = get_uid(path, follow_symlinks)
     if uid == -1:
         return False
     return uid_to_user(uid)
@@ -271,6 +293,11 @@ def chown(path, user, group):
         else:
             gid = -1
     if not os.path.exists(path):
+        try:
+            # Broken symlinks will return false, but still need to be chowned
+            return os.lchown(path, uid, gid)
+        except OSError:
+            pass
         err += 'File not found'
     if err:
         return err
@@ -470,6 +497,8 @@ def _sed_esc(string, escape_all=False):
 def sed(path, before, after, limit='', backup='.bak', options='-r -e',
         flags='g', escape_all=False):
     '''
+    .. versionadded:: 0.9.5
+
     Make a simple edit to a file
 
     Equivalent to::
@@ -500,8 +529,6 @@ def sed(path, before, after, limit='', backup='.bak', options='-r -e',
     CLI Example::
 
         salt '*' file.sed /etc/httpd/httpd.conf 'LogLevel warn' 'LogLevel info'
-
-    .. versionadded:: 0.9.5
     '''
     # Largely inspired by Fabric's contrib.files.sed()
     # XXX:dc: Do we really want to always force escaping?
@@ -568,6 +595,8 @@ def sed_contains(path, text, limit='', flags='g'):
 def psed(path, before, after, limit='', backup='.bak', flags='gMS',
          escape_all=False, multi=False):
     '''
+    .. versionadded:: 0.9.5
+
     Make a simple edit to a file (pure Python version)
 
     Equivalent to::
@@ -604,8 +633,6 @@ def psed(path, before, after, limit='', backup='.bak', flags='gMS',
     CLI Example::
 
         salt '*' file.sed /etc/httpd/httpd.conf 'LogLevel warn' 'LogLevel info'
-
-    .. versionadded:: 0.9.5
     '''
     # Largely inspired by Fabric's contrib.files.sed()
     # XXX:dc: Do we really want to always force escaping?
@@ -668,6 +695,8 @@ def _psed(text, before, after, limit, flags):
 
 def uncomment(path, regex, char='#', backup='.bak'):
     '''
+    .. versionadded:: 0.9.5
+
     Uncomment specified commented lines in a file
 
     path
@@ -687,8 +716,6 @@ def uncomment(path, regex, char='#', backup='.bak'):
     CLI Example::
 
         salt '*' file.uncomment /etc/hosts.deny 'ALL: PARANOID'
-
-    .. versionadded:: 0.9.5
     '''
     # Largely inspired by Fabric's contrib.files.uncomment()
 
@@ -701,6 +728,8 @@ def uncomment(path, regex, char='#', backup='.bak'):
 
 def comment(path, regex, char='#', backup='.bak'):
     '''
+    .. versionadded:: 0.9.5
+
     Comment out specified lines in a file
 
     path
@@ -725,8 +754,6 @@ def comment(path, regex, char='#', backup='.bak'):
     CLI Example::
 
         salt '*' file.comment /etc/modules pcspkr
-
-    .. versionadded:: 0.9.5
     '''
     # Largely inspired by Fabric's contrib.files.comment()
 
@@ -743,6 +770,8 @@ def comment(path, regex, char='#', backup='.bak'):
 
 def patch(originalfile, patchfile, options='', dry_run=False):
     '''
+    .. versionadded:: 0.10.4
+
     Apply a patch to a file
 
     Equivalent to::
@@ -759,8 +788,6 @@ def patch(originalfile, patchfile, options='', dry_run=False):
     CLI Example::
 
         salt '*' file.patch /opt/file.txt /tmp/file.txt.patch
-
-    .. versionadded:: 0.10.4
     '''
     if dry_run:
         if __grains__['kernel'] in ('FreeBSD', 'OpenBSD'):
@@ -776,18 +803,18 @@ def patch(originalfile, patchfile, options='', dry_run=False):
 
 def contains(path, text):
     '''
-    Return True if the file at ``path`` contains ``text``
+    .. versionadded:: 0.9.5
+
+    Return ``True`` if the file at ``path`` contains ``text``
 
     CLI Example::
 
         salt '*' file.contains /etc/crontab 'mymaintenance.sh'
-
-    .. versionadded:: 0.9.5
     '''
     if not os.path.exists(path):
         return False
 
-    stripped_text = text.strip()
+    stripped_text = str(text).strip()
     try:
         with salt.utils.filebuffer.BufferedReader(path) as breader:
             for chunk in breader:
@@ -873,6 +900,8 @@ def contains_glob(path, glob):
 
 def append(path, *args):
     '''
+    .. versionadded:: 0.9.5
+
     Append text to the end of a file
 
     CLI Example::
@@ -880,8 +909,6 @@ def append(path, *args):
         salt '*' file.append /etc/motd \\
                 "With all thine offerings thou shalt offer salt."\\
                 "Salt is what makes things taste bad when it isn't in them."
-
-    .. versionadded:: 0.9.5
     '''
     # Largely inspired by Fabric's contrib.files.append()
 
@@ -894,9 +921,10 @@ def append(path, *args):
 
 def touch(name, atime=None, mtime=None):
     '''
-    Just like 'nix's "touch" command, create a file if it
-    doesn't exist or simply update the atime and mtime if
-    it already does.
+    .. versionadded:: 0.9.5
+
+    Just like *nix's ``touch`` command, create a file if it doesn't exist or
+    simply update the atime and mtime if it already does.
 
     atime:
         Access time in Unix epoch time
@@ -906,8 +934,6 @@ def touch(name, atime=None, mtime=None):
     CLI Example::
 
         salt '*' file.touch /var/log/emptyfile
-
-    .. versionadded:: 0.9.5
     '''
     if atime and atime.isdigit():
         atime = int(atime)
