@@ -13,6 +13,7 @@ import salt.payload
 
 log = logging.getLogger(__name__)
 
+
 def _auth():
     '''
     Return the auth object
@@ -46,11 +47,8 @@ def update(clear=False):
     data = {}
     for func in m_data:
         if func not in __salt__:
-            log.error(
-                    'Function {0} in mine_functions not available'.format(
-                        func
-                        )
-                    )
+            log.error('Function {0} in mine_functions not available'
+                      .format(func))
             continue
         try:
             if m_data[func] and isinstance(m_data[func], dict):
@@ -60,18 +58,15 @@ def update(clear=False):
             else:
                 data[func] = __salt__[func]()
         except Exception:
-            log.error(
-                    'Function {0} in mine_functions failed to execute'.format(
-                        func
-                        )
-                    )
+            log.error('Function {0} in mine_functions failed to execute'
+                      .format(func))
             continue
     load = {
             'cmd': '_mine',
             'data': data,
             'id': __opts__['id'],
             'clear': clear,
-            }
+    }
     sreq = salt.payload.SREQ(__opts__['master_uri'])
     auth = _auth()
     try:
@@ -108,17 +103,14 @@ def send(func, *args, **kwargs):
         else:
             data[func] = __salt__[func](*f_call['args'])
     except Exception as exc:
-        log.error(
-                'Function {0} in mine.send failed to execute'.format(
-                    func
-                    )
-                )
+        log.error('Function {0} in mine.send failed to execute: {1}'
+                  .format(func, exc))
         return False
     load = {
             'cmd': '_mine',
             'data': data,
             'id': __opts__['id'],
-            }
+    }
     sreq = salt.payload.SREQ(__opts__['master_uri'])
     auth = _auth()
     try:
@@ -153,7 +145,7 @@ def get(tgt, fun, expr_form='glob'):
             'tgt': tgt,
             'fun': fun,
             'expr_form': expr_form,
-            }
+    }
     sreq = salt.payload.SREQ(__opts__['master_uri'])
     ret = sreq.send('aes', auth.crypticle.dumps(load))
     return auth.crypticle.loads(ret)
