@@ -972,7 +972,10 @@ def user_grants(user,
     ret = []
     results = cur.fetchall()
     for grant in results:
-        ret.append(grant[0].split(' IDENTIFIED BY')[0])
+        tmp = grant[0].split(' IDENTIFIED BY')[0]
+        if 'WITH GRANT OPTION' in grant[0]:
+            tmp = '{} WITH GRANT OPTION'.format(tmp)
+        ret.append(tmp)
     log.debug(ret)
     return ret
 
