@@ -240,7 +240,7 @@ def check_key_file(user, source, config='.ssh/authorized_keys', env='base'):
     '''
     keyfile = __salt__['cp.cache_file'](source, env)
     if not keyfile:
-        return ret
+        return {}
     s_keys = _validate_keys(keyfile)
     if not s_keys:
         err = 'No keys detected in {0}. Is file properly ' \
@@ -508,11 +508,17 @@ def recv_known_host(hostname, enc=None, port=None, hash_hostname=False):
 
         salt '*' ssh.recv_known_host <hostname> enc=<enc> port=<port>
     '''
+    # The following list of OSes have an old version of openssh-clients
+    # and thus require the '-t' option for ssh-keyscan
+    need_dash_t = ['CentOS-5',]
+
     chunks = ['ssh-keyscan', ]
     if port:
         chunks += ['-p', str(port)]
     if enc:
         chunks += ['-t', str(enc)]
+    if not enc and __grains__.get('osfinger') in need_dash_t:
+        chunks += ['-t', 'rsa']
     if hash_hostname:
         chunks.append('-H')
     chunks.append(str(hostname))
