@@ -212,13 +212,14 @@ def highstate(test=None, **kwargs):
 
     # Not 100% if this should be fatal or not,
     # but I'm guessing it likely should not be.
+    cumask = os.umask(191)
     try:
         with salt.utils.fopen(cache_file, 'w+') as fp_:
             serial.dump(ret, fp_)
     except (IOError, OSError):
         msg = 'Unable to write to "state.highstate" cache file {0}'
         log.error(msg.format(cache_file))
-
+    os.umask(cumask)
     _set_retcode(ret)
     return ret
 
@@ -291,12 +292,14 @@ def sls(mods, env='base', test=None, exclude=None, **kwargs):
     if __salt__['config.option']('state_data', '') == 'terse' or kwargs.get('terse'):
         ret = _filter_running(ret)
     cache_file = os.path.join(__opts__['cachedir'], 'sls.p')
+    cumask = os.umask(191)
     try:
         with salt.utils.fopen(cache_file, 'w+') as fp_:
             serial.dump(ret, fp_)
     except (IOError, OSError):
         msg = 'Unable to write to "state.sls" cache file {0}'
         log.error(msg.format(cache_file))
+    os.umask(cumask)
     _set_retcode(ret)
     with open(cfn, 'w+') as fp_:
         try:
@@ -387,8 +390,6 @@ def show_lowstate():
         ret = st_.compile_low_chunks()
     finally:
         st_.pop_active()
-    if isinstance(ret, list):
-        __context__['retcode'] = 1
     return ret
 
 
