@@ -19,6 +19,7 @@ from salt.version import __version__
 
 log = logging.getLogger(__name__)
 
+
 def get_pillar(opts, grains, id_, env=None, ext=None):
     '''
     Return the correct pillar driver based on the file_client option
@@ -110,7 +111,7 @@ class Pillar(object):
             if 'ext_pillar' in opts:
                 opts['ext_pillar'].append(ext)
             else:
-                opts['ext_pillar'].append(ext)
+                opts['ext_pillar'] = [ext]
         return opts
 
     def _get_envs(self):
@@ -269,27 +270,34 @@ class Pillar(object):
         errors = []
         fn_ = self.client.get_state(sls, env).get('dest', False)
         if not fn_:
-            errors.append(('Specified SLS {0} in environment {1} is not'
-                           ' available on the salt master').format(sls, env))
+            msg = ('Specified SLS {0!r} in environment {1!r} is not'
+                   ' available on the salt master').format(sls, env)
+            log.error(msg)
+            errors.append(msg)
         state = None
         try:
             state = compile_template(
                 fn_, self.rend, self.opts['renderer'], env, sls)
         except Exception as exc:
-            errors.append(('Rendering SLS {0} failed, render error:\n{1}'
-                           .format(sls, exc)))
+            msg = 'Rendering SLS {0!r} failed, render error:\n{1}'.format(
+                sls, exc
+            )
+            log.error(msg)
+            errors.append(msg)
         mods.add(sls)
         nstate = None
         if state:
             if not isinstance(state, dict):
-                errors.append(('SLS {0} does not render to a dictionary'
-                               .format(sls)))
+                msg = 'SLS {0!r} does not render to a dictionary'.format(sls)
+                log.error(msg)
+                errors.append(msg)
             else:
                 if 'include' in state:
                     if not isinstance(state['include'], list):
-                        err = ('Include Declaration in SLS {0} is not formed '
-                               'as a list'.format(sls))
-                        errors.append(err)
+                        msg = ('Include Declaration in SLS {0!r} is not '
+                               'formed as a list'.format(sls))
+                        log.error(msg)
+                        errors.append(msg)
                     else:
                         for sub_sls in state.pop('include'):
                             if sub_sls not in mods:
@@ -315,10 +323,24 @@ class Pillar(object):
             mods = set()
             for sls in pstates:
                 pstate, mods, err = self.render_pstate(sls, env, mods)
-                if pstate:
-                    pillar.update(pstate)
+
                 if err:
                     errors += err
+
+                if pstate is not None:
+                    if not isinstance(pstate, dict):
+                        log.error(
+                            'The rendered pillar sls file, {0!r} state did '
+                            'not return the expected data format. This is '
+                            'a sign of a malformed pillar sls file. Returned '
+                            'errors: {1}'.format(
+                                sls,
+                                ', '.join(['{0!r}'.format(e) for e in errors])
+                            )
+                        )
+                        continue
+                    pillar.update(pstate)
+
         return pillar, errors
 
     def ext_pillar(self, pillar):
@@ -359,7 +381,7 @@ class Pillar(object):
 
     def compile_pillar(self):
         '''
-        Render the pillar dta and return
+        Render the pillar data and return
         '''
         top, terrors = self.get_top()
         matches = self.top_matches(top)
