@@ -41,15 +41,17 @@ import re
 import salt.utils
 
 if salt.utils.is_windows():
-    from salt.utils import namespaced_function
+    from salt.utils import namespaced_function as _namespaced_function
     from salt.modules.win_pkg import _get_package_info
     from salt.modules.win_pkg import get_repo_data
     from salt.modules.win_pkg import _get_latest_pkg_version
     from salt.modules.win_pkg import _reverse_cmp_pkg_versions
-    _get_package_info = namespaced_function(_get_package_info, globals())
-    get_repo_data = namespaced_function(get_repo_data, globals())
-    _get_latest_pkg_version = namespaced_function(_get_latest_pkg_version, globals())
-    _reverse_cmp_pkg_versions = namespaced_function(_reverse_cmp_pkg_versions, globals())
+    _get_package_info = _namespaced_function(_get_package_info, globals())
+    get_repo_data = _namespaced_function(get_repo_data, globals())
+    _get_latest_pkg_version = \
+            _namespaced_function(_get_latest_pkg_version, globals())
+    _reverse_cmp_pkg_versions = \
+            _namespaced_function(_reverse_cmp_pkg_versions, globals())
     # The following imports are used by the namespaced win_pkg funcs
     # and need to be included in their globals.
     import msgpack
