@@ -28,8 +28,7 @@ def __virtual__():
 def present(name,
            password=None,
            force=False,
-           runas=None,
-        ):
+           runas=None):
     '''
     Ensure the RabbitMQ user exists.
 
@@ -90,8 +89,7 @@ def present(name,
 
 
 def absent(name,
-           runas=None,
-        ):
+           runas=None):
     '''
     Ensure the named user is absent
 
