@@ -4,6 +4,7 @@ Some of the utils used by salt
 from __future__ import absolute_import
 
 # Import python libs
+import fnmatch
 import os
 import re
 import imp
@@ -25,6 +26,7 @@ import types
 import warnings
 import zmq
 from calendar import month_abbr as months
+from functools import wraps
 import salt._compat
 
 try:
@@ -805,6 +807,7 @@ def memoize(func):
     '''
     cache = {}
 
+    @wraps(func)
     def _memoize(*args):
         if args not in cache:
             cache[args] = func(*args)
@@ -835,7 +838,50 @@ def fopen(*args, **kwargs):
     return fhandle
 
 
-def traverse_dict(data, target, default, delim=':'):
+def subdict_match(data, expr, delim=':', regex_match=False):
+    '''
+    Check for a match in a dictionary using a delimiter character to denote
+    levels of subdicts, and also allowing the delimiter character to be
+    matched. Thus, 'foo:bar:baz' will match data['foo'] == 'bar:baz' and
+    data['foo']['bar'] == 'baz'. The former would take priority over the
+    latter.
+    '''
+    def _match(target, pattern, regex_match=False):
+        if regex_match:
+            try:
+                return re.match(pattern.lower(), str(target).lower())
+            except Exception:
+                log.error('Invalid regex \'{0}\' in match'.format(pattern))
+                return False
+        else:
+            return fnmatch.fnmatch(str(target).lower(), pattern.lower())
+
+    for idx in range(1, expr.count(delim) + 1):
+        splits = expr.split(delim)
+        key = delim.join(splits[:idx])
+        matchstr = delim.join(splits[idx:])
+        log.debug('Attempting to match \'{0}\' in \'{1}\' using delimiter '
+                  '\'{2}\''.format(matchstr, key, delim))
+        match = traverse_dict(data, key, {}, delim=delim)
+        if match == {}:
+            continue
+        if isinstance(match, dict):
+            if matchstr == '*':
+                # We are just checking that the key exists
+                return True
+            continue
+        if isinstance(match, list):
+            # We are matching a single component to a single list member
+            for member in match:
+                if _match(member, matchstr, regex_match=regex_match):
+                    return True
+            continue
+        if _match(match, matchstr, regex_match=regex_match):
+            return True
+    return False
+
+
+def traverse_dict(data, key, default, delim=':'):
     '''
     Traverse a dict using a colon-delimited (or otherwise delimited, using
     the "delim" param) target string. The target 'foo:bar:baz' will return
@@ -843,7 +889,7 @@ def traverse_dict(data, target, default, delim=':'):
     return an empty dict.
     '''
     try:
-        for each in target.split(delim):
+        for each in key.split(delim):
             data = data[each]
     except (KeyError, IndexError, TypeError):
         # Encountered a non-indexable value in the middle of traversing
