@@ -3,6 +3,7 @@ Set up the Salt integration test suite
 '''
 
 # Import Python libs
+import re
 import optparse
 import multiprocessing
 import os
@@ -29,6 +30,7 @@ import salt.master
 import salt.minion
 import salt.runner
 import salt.output
+import salt.version
 from salt.utils import fopen, get_colors
 from salt.utils.verify import verify_env
 from saltunittest import TestCase, RedirectStdStreams
@@ -271,9 +273,8 @@ class TestDaemon(object):
         self.setup_minions()
 
         if self.opts.sysinfo:
-            from salt import version
             print_header('~~~~~~~ Versions Report ', inline=True)
-            print('\n'.join(version.versions_report()))
+            print('\n'.join(salt.version.versions_report()))
 
             print_header(
                 '~~~~~~~ Minion Grains Information ', inline=True,
@@ -604,7 +605,9 @@ class ModuleCase(TestCase, SaltClientTestCaseMixIn):
         Run a single salt function and condition the return down to match the
         behavior of the raw function call
         '''
-        know_to_return_none = ('file.chown', 'file.chgrp')
+        know_to_return_none = (
+            'file.chown', 'file.chgrp', 'ssh.recv_known_host'
+        )
         orig = self.client.cmd(
             minion_tgt, function, arg, timeout=timeout, kwarg=kwargs
         )
@@ -720,8 +723,6 @@ class ShellCase(TestCase):
             term_sent = False
             while True:
                 process.poll()
-                if process.returncode is not None:
-                    break
 
                 if datetime.now() > stop_at:
                     if term_sent is False:
@@ -732,8 +733,12 @@ class ShellCase(TestCase):
                         term_sent = True
                         continue
 
-                    # As a last resort, kill the process group
-                    os.killpg(os.getpgid(process.pid), signal.SIGKILL)
+                    try:
+                        # As a last resort, kill the process group
+                        os.killpg(os.getpgid(process.pid), signal.SIGKILL)
+                    except OSError as exc:
+                        if exc.errno != 3:
+                            raise
 
                     out = [
                         'Process took more than {0} seconds to complete. '
@@ -745,6 +750,9 @@ class ShellCase(TestCase):
                         ]
                     return out
 
+                if process.returncode is not None:
+                    break
+
         if catch_stderr:
             if sys.version_info < (2, 7):
                 # On python 2.6, the subprocess'es communicate() method uses
@@ -858,14 +866,14 @@ class ShellCaseCommonTestsMixIn(object):
         if getattr(self, '_call_binary_', None) is None:
             self.skipTest('\'_call_binary_\' not defined.')
         from salt.utils import which
-        from salt.version import __version_info__
+        from salt.version import __version_info__, GIT_DESCRIBE_REGEX
         git = which('git')
         if not git:
             self.skipTest('The git binary is not available')
 
         # Let's get the output of git describe
         process = subprocess.Popen(
-            [git, 'describe'],
+            [git, 'describe', '--tags', '--match', 'v[0-9]*'],
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             close_fds=True,
@@ -880,18 +888,27 @@ class ShellCaseCommonTestsMixIn(object):
                 )
             )
 
-        parsed_version = '{0}'.format(out.strip().lstrip('v'))
+        match = re.search(GIT_DESCRIBE_REGEX, out)
+        if not match:
+            return version, version_info
+
+        parsed_version = '{0}.{1}.{2}'.format(
+            match.group('major'),
+            match.group('minor'),
+            match.group('bugfix') or '0'
+        )
         parsed_version_info = tuple([
-            int(i) for i in parsed_version.split('-', 1)[0].split('.')
+            int(g) for g in [h or '0' for h in match.groups()[:3]]
+            if g.isdigit()
         ])
         if parsed_version_info and parsed_version_info < __version_info__:
             self.skipTest(
-                'We\'re likely about to release a new version. '
-                'This test would fail. Parsed({0!r}) < Expected({1!r})'.format(
+                'We\'re likely about to release a new version. This test '
+                'would fail. Parsed({0!r}) < Expected({1!r})'.format(
                     parsed_version_info, __version_info__
                 )
             )
-        elif parsed_version_info != __version_info__:
+        elif parsed_version_info != salt.version.__version_info__:
             self.skipTest(
                 'In order to get the proper salt version with the '
                 'git hash you need to update salt\'s local git '
@@ -1050,3 +1067,110 @@ class SaltReturnAssertsMixIn(object):
         return self.assertNotEqual(
             self.__getWithinSaltReturn(ret, keys), comparison
         )
+
+
+# ----- salt 0.16.x network tests wrapper ----------------------------------->
+# If you're removing this code because we're already in salt 0.17, please also
+# switch the `requires_network` import in `tests/unit/utils/verify_test.py`
+if salt.version.__version_info__ >= (0, 17):
+    raise RuntimeError(
+        'Detected salt >= 0.17.0. Please remove this `requires_network` '
+        'function which was only meant to be used in salt < 0.17'
+    )
+
+try:
+    from salttesting.helpers import requires_network
+except ImportError:
+    if salt.version.__version_info__ >= (0, 17):
+        # If you're removing this code because we're already in salt 0.17,
+        # please also switch the `requires_network` import line in
+        # `tests/unit/utils/verify_test.py`
+        raise RuntimeError(
+            'Detected salt >= 0.17.0. Please remove this `requires_network` '
+            'function which was only meant to be used in salt < 0.17'
+        )
+
+    import socket
+    from functools import wraps
+
+    def requires_network(only_local_network=False):
+        '''
+        Simple decorator which is supposed to skip a test case in case there's
+        no network connection to the internet.
+        '''
+        def decorator(func):
+            @wraps(func)
+            def wrap(cls):
+                has_local_network = False
+                # First lets try if we have a local network. Inspired in
+                # verify_socket
+                try:
+                    pubsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                    retsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                    pubsock.setsockopt(
+                        socket.SOL_SOCKET, socket.SO_REUSEADDR, 1
+                    )
+                    pubsock.bind(('', 18000))
+                    pubsock.close()
+                    retsock.setsockopt(
+                        socket.SOL_SOCKET, socket.SO_REUSEADDR, 1
+                    )
+                    retsock.bind(('', 18001))
+                    retsock.close()
+                    has_local_network = True
+                except socket.error:
+                    # I wonder if we just have IPV6 support?
+                    try:
+                        pubsock = socket.socket(
+                            socket.AF_INET, socket.SOCK_STREAM
+                        )
+                        retsock = socket.socket(
+                            socket.AF_INET, socket.SOCK_STREAM
+                        )
+                        pubsock.setsockopt(
+                            socket.SOL_SOCKET, socket.SO_REUSEADDR, 1
+                        )
+                        pubsock.bind(('', 18000))
+                        pubsock.close()
+                        retsock.setsockopt(
+                            socket.SOL_SOCKET, socket.SO_REUSEADDR, 1
+                        )
+                        retsock.bind(('', 18001))
+                        retsock.close()
+                        has_local_network = True
+                    except socket.error:
+                        # Let's continue
+                        pass
+
+                if only_local_network is True:
+                    if has_local_network is False:
+                        # Since we're only supposed to check local network, and
+                        # no local network was detected, skip the test
+                        cls.skipTest('No local network was detected')
+                    return func(cls)
+
+                # We are using the google.com DNS records as numerical IPs to
+                # avoid DNS lookups which could greatly slow down this check
+                for addr in ('173.194.41.198', '173.194.41.199',
+                             '173.194.41.200', '173.194.41.201',
+                             '173.194.41.206', '173.194.41.192',
+                             '173.194.41.193', '173.194.41.194',
+                             '173.194.41.195', '173.194.41.196',
+                             '173.194.41.197'):
+                    try:
+                        sock = socket.socket(socket.AF_INET,
+                                             socket.SOCK_STREAM)
+                        sock.settimeout(0.25)
+                        sock.connect((addr, 80))
+                        sock.close()
+                        # We connected? Stop the loop
+                        break
+                    except socket.error:
+                        # Let's check the next IP
+                        continue
+                else:
+                    cls.skipTest('No internet network connection was detected')
+                return func(cls)
+            return wrap
+        return decorator
+# <---- salt 0.16.x network tests wrapper ------------------------------------
