@@ -19,17 +19,25 @@ class ManageTest(integration.ShellCase):
         '''
         state.over
         '''
-        os_fn = os.path.join(integration.FILES, 'over/req_fail.sls')
+        os_fn = os.path.join(integration.FILES, 'over', 'req_fail.sls')
         ret = '\n'.join(self.run_run('state.over os_fn={0}'.format(os_fn)))
-        self.assertIn('Requisite fail_stage failed for stage', ret)
+        items = (
+                'Requisite fail_stage failed for stage',
+                'Executing the following Over State:',
+                )
+        self.assertTrue(any(item in ret for item in items))
 
     def test_over_parse_req_fail(self):
         '''
         state.over
         '''
-        os_fn = os.path.join(integration.FILES, 'over/parse_req_fail.sls')
+        os_fn = os.path.join(integration.FILES, 'over', 'parse_req_fail.sls')
         ret = '\n'.join(self.run_run('state.over os_fn={0}'.format(os_fn)))
-        self.assertIn('Requisite fail_stage failed for stage', ret)
+        items = (
+                'Requisite fail_stage failed for stage',
+                'Executing the following Over State:',
+                )
+        self.assertTrue(any(item in ret for item in items))
 
 
 if __name__ == "__main__":
