@@ -1,14 +1,7 @@
 '''
 tests for host state
 '''
-
-# Import python libs
-import os
-#
-# Import salt libs
-from saltunittest import TestLoader, TextTestRunner
 import integration
-from integration import TestDaemon
 
 
 class CompileTest(integration.ModuleCase):
@@ -22,3 +15,8 @@ class CompileTest(integration.ModuleCase):
         ret = self.run_function('state.sls', mods='fuzz.multi_state')
         # Verify that the return is a list, aka, an error
         self.assertIsInstance(ret, list)
+
+
+if __name__ == '__main__':
+    from integration import run_tests
+    run_tests(CompileTest)
