@@ -206,7 +206,7 @@ class TestFind(TestCase):
             ValueError, salt.utils.find.GroupOption, 'group', 'notexist'
         )
 
-        if sys.platform == 'darwin':
+        if sys.platform.startswith(('darwin', 'freebsd')):
             group_name = 'wheel'
         else:
             group_name = 'root'
@@ -215,7 +215,7 @@ class TestFind(TestCase):
 
     @skipIf(sys.platform.startswith('win'), 'No /dev/null on Windows')
     def test_group_option_match(self):
-        if sys.platform == 'darwin':
+        if sys.platform.startswith(('darwin', 'freebsd')):
             group_name = 'wheel'
         else:
             group_name = 'root'
@@ -391,7 +391,7 @@ class TestPrintOption(TestCase):
     @skipIf(sys.platform.startswith('Windows'), "no /dev/null on windows")
     def test_print_group(self):
         option = salt.utils.find.PrintOption('print', 'group')
-        if sys.platform == 'darwin':
+        if sys.platform.startswith(('darwin', 'freebsd')):
             group_name = 'wheel'
         else:
             group_name = 'root'
@@ -485,7 +485,7 @@ class TestFinder(TestCase):
             str(finder.criteria[0].__class__)[-13:-2], 'OwnerOption'
         )
 
-        if sys.platform == 'darwin':
+        if sys.platform.startswith(('darwin', 'freebsd')):
             group_name = 'wheel'
         else:
             group_name = 'root'
